* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder)
  * Sample Prompts for the Inventory Builder
